{% extends "responsive_dashboard/dashlet.html" %}
{% load admin_urls %}

{% block dashlet_body %}
<table>
    <tbody>
    {% for ct in content_types %}
        <tr>
            <td><a href="{{ ct.change_url }}">{{ ct|capfirst }}</a></td>
            <td><a href="{{ ct.change_url }}"> Edit </a></td>
        </tr>
    {% endfor %}
    </tbody>
</table>
{% endblock %}
